@@ -19,7 +19,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 our @aliens;
@@ -128,7 +128,7 @@ sub _flags
 {
   my($class, $method) = @_;
   my $static = "${method}_static";
-  $class->can($static)
+  $class->can($static) && $class->can('install_type') && $class->install_type eq 'share'
     ? $class->$static
     : $class->$method;
 }
@@ -449,7 +449,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
